---
name: ✨ Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

Please use https://app.revenuecat.com/settings/support instead of opening an issue. That is the best channel that allows us to keep track of feature requests.
